@@ -1162,15 +1162,32 @@ PYBIND11_MODULE(_multinet, m) {
         )pbdoc");
 
     /*********************************************************************************/
-    /*m.def("project", &project,
+    m.def("project", &project,
         py::arg("n"),
         py::arg("new.layer") = "projection",
         py::arg("layer1"),
         py::arg("layer2"),
         py::arg("method") = "clique",
         R"pbdoc(
-        Adds a new layer with the actors in layer 1, and edges between actors A and B if they are connected to a common object in layer 2)pbdoc");
-     */
+        Adds a new layer with the actors in layer 1, and edges between actors A and B if they are connected to a common object in layer 2.
+          
+        Parameters
+        ----------
+        n : PyMLNetwork
+            A multilayer network.
+        new.layer : str
+            Name of the new layer.
+        layer1 : str
+            Name of the layer from which actors are taken.
+        layer2 : str
+            Name of the layer to be projected on layer1.
+        method : str
+            Currently only the "clique" method is implemented, creating an edge between A and be
+            if they are adjacent to at least one common object on layer2.
+          
+        See Also
+        ________
+        )pbdoc");
 
     /**************************************/
     /* MEASURES                       */
