@@ -13,6 +13,7 @@
 #include "pycpp_utils.hpp"
 
 #include "operations/union.hpp"
+#include "operations/project.hpp"
 #include "community/glouvain.hpp"
 #include "community/abacus.hpp"
 #include "community/infomap.hpp"
@@ -1797,23 +1798,26 @@ flatten(
 }
 
 
-/*
 void project(
     PyMLNetwork& rmnet,
     const std::string& new_layer,
     const std::string& layer_name1,
     const std::string& layer_name2,
-    const std::string& method) {
+    const std::string& method)
+{
 auto mnet = rmnet.get_mlnet();
 auto layer1 = mnet->layers()->get(layer_name1);
 auto layer2 = mnet->layers()->get(layer_name2);
 if (!layer1 || !layer2)
     throw std::runtime_error("Layer not found");
-if (method=="clique")
-    project_unweighted(mnet,new_layer,layer1,layer2);
-else throw std::runtime_error("Unexpected value: algorithm");
+    if (method=="clique")
+    {
+        auto target = std::make_unique<G>(new_layer, uu::net::EdgeDir::UNDIRECTED, true);
+        auto target_ptr = mnet->layers()->add(std::move(target));
+        uu::net::project_unweighted(mnet, layer1, layer2, target_ptr);
+    }
+    else throw std::runtime_error("Unexpected value: method");
 }
-*/
 
 // MEASURES
 
