@@ -71,7 +71,7 @@ try:
     # attributes
     add_attributes, attributes, get_values, set_values,
     # transformation
-    flatten,
+    flatten, project,
     # measures
     degree, degree_deviation, neighborhood, xneighborhood, connective_redundancy,
     relevance, xrelevance,
